pub struct Span {
pub begin: Position,
pub end: Position,
}Expand description
A Span represents an arbitrary source range. It includes the beginning and ending Positions.
Fields
begin: Positionend: PositionImplementations
Sourceimpl Span
impl Span
Sourcepub fn new(
begin_line: usize,
begin_column: usize,
end_line: usize,
end_column: usize,
) -> Self
pub fn new( begin_line: usize, begin_column: usize, end_line: usize, end_column: usize, ) -> Self
Create a new Span. The beginning and ending Positions will also be created.
Arguments
begin_lineThe line number for the beginning of the Span, where the first line of the file is at zero.begin_columnThe column number for the beginning of the Span, where the first column of a line is at zero.end_lineThe line number for the ending of the Span, where the first line of the file is at zero.end_columnThe column number for the ending of the Span, where the first column of a line is at zero.
Return
A new Span, with new beginning and ending Positions.
Sourcepub fn from_begin_end<Pos>(begin: Pos, end: Pos) -> Self
pub fn from_begin_end<Pos>(begin: Pos, end: Pos) -> Self
pub fn merge(self, other: Span) -> Span